==> analysis2.3.1r2.tar.gz: ccpnmr/ccpnmr2.3/python/ccpnmr/format/converters/TargetedAcquisitionFormat.py <==
"""
======================COPYRIGHT/LICENSE START==========================

TargetedAcquisitionFormat.py: Contains functions specific to 
TargetedAcquisition

Copyright (C) 2011 Maxim Mayzel

=======================================================================

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.
 
A copy of this license can be found in ../../../../license/LGPL.license
 
This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.
 
You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA


======================COPYRIGHT/LICENSE END============================

for further information, please contact :

- CCPN website (http://www.ccpn.ac.uk/)
- PDBe website (http://www.ebi.ac.uk/pdbe/)

- contact Maxim Mayzel (maxim.mayzel@nmr.gu.se)
=======================================================================

If you are using this software for academic purposes, we suggest
quoting the following references:

===========================REFERENCE START=============================
R. Fogh, J. Ionides, E. Ulrich, W. Boucher, W. Vranken, J.P. Linge, M.
Habeck, W. Rieping, T.N. Bhat, J. Westbrook, K. Henrick, G. Gilliland,
H. Berman, J. Thornton, M. Nilges, J. Markley and E. Laue (2002). The
CCPN project: An interim report on a data model for the NMR community
(Progress report). Nature Struct. Biol. 9, 416-418.

Wim F. Vranken, Wayne Boucher, Tim J. Stevens, Rasmus
H. Fogh, Anne Pajon, Miguel Llinas, Eldon L. Ulrich, John L. Markley, John
Ionides and Ernest D. Laue (2005). The CCPN Data Model for NMR Spectroscopy:
Development of a Software Pipeline. Proteins 59, 687 - 696.

===========================REFERENCE END===============================
"""

from ccpnmr.format.converters.DataFormat import DataFormat, IOkeywords

from ccpnmr.format.general.Constants import volume_kw, height_kw

from memops.api import Implementation
from ccp.api.nmr import Nmr

import copy, os

IOkeywords = copy.deepcopy(IOkeywords)

class TargetedAcquisitionFormat(DataFormat):

  def setFormat(self):

    self.format = 'targetedAcquisition'
    self.IOkeywords = IOkeywords

  def setGenericImports(self):

    self.getMeasurements = self.getMeasurementsGeneric

==> analysis2.4.2.tar.gz: ccpnmr/ccpnmr2.4/python/ccpnmr/format/converters/TargetedAcquisitionFormat.py <==
"""
======================COPYRIGHT/LICENSE START==========================

TargetedAcquisitionFormat.py: Contains functions specific to 
TargetedAcquisition

Copyright (C) 2011 Maxim Mayzel

=======================================================================

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.
 
A copy of this license can be found in ../../../../license/LGPL.license
 
This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.
 
You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA


======================COPYRIGHT/LICENSE END============================

for further information, please contact :

- CCPN website (http://www.ccpn.ac.uk/)
- PDBe website (http://www.ebi.ac.uk/pdbe/)

- contact Maxim Mayzel (maxim.mayzel@nmr.gu.se)
=======================================================================

If you are using this software for academic purposes, we suggest
quoting the following references:

===========================REFERENCE START=============================
R. Fogh, J. Ionides, E. Ulrich, W. Boucher, W. Vranken, J.P. Linge, M.
Habeck, W. Rieping, T.N. Bhat, J. Westbrook, K. Henrick, G. Gilliland,
H. Berman, J. Thornton, M. Nilges, J. Markley and E. Laue (2002). The
CCPN project: An interim report on a data model for the NMR community
(Progress report). Nature Struct. Biol. 9, 416-418.

Wim F. Vranken, Wayne Boucher, Tim J. Stevens, Rasmus
H. Fogh, Anne Pajon, Miguel Llinas, Eldon L. Ulrich, John L. Markley, John
Ionides and Ernest D. Laue (2005). The CCPN Data Model for NMR Spectroscopy:
Development of a Software Pipeline. Proteins 59, 687 - 696.

===========================REFERENCE END===============================
"""

from ccpnmr.format.converters.DataFormat import DataFormat, IOkeywords

from memops.api import Implementation
from ccp.api.nmr import Nmr

import copy, os

IOkeywords = copy.deepcopy(IOkeywords)
IOkeywords['readShifts']['createNewMolSystem'] = (False,False,"Create new molecular system from the assignment file")
IOkeywords['readShifts']['minimalProbability']=(0.25,True,"Set the minimum assignment probability threshold.")
IOkeywords['readShifts']['chain'] = (None,True,'The chain to be populated with imported shifts.')

class TargetedAcquisitionFormat(DataFormat):

  def setFormat(self):

    self.format = 'targetedAcquisition'
    self.IOkeywords = IOkeywords

  def setGenericImports(self):

    self.getMeasurements = self.getMeasurementsGeneric

  def thisAssignmentValid(self):
    
    isValid = False
    
    #print self.rawMeasurement.__dict__
    if self.rawMeasurement.figOfMerit > self.minimalProbability:
      isValid = True
    
    return isValid
